@@ -2,14 +2,14 @@
  * BRLTTY - A background process providing access to the console screen (when in
  *          text mode) for a blind person using a refreshable braille display.
  *
- * Copyright (C) 1995-2016 by The BRLTTY Developers.
+ * Copyright (C) 1995-2018 by The BRLTTY Developers.
  *
  * BRLTTY comes with ABSOLUTELY NO WARRANTY.
  *
  * This is free software, placed under the terms of the
- * GNU General Public License, as published by the Free Software
- * Foundation; either version 2 of the License, or (at your option) any
- * later version. Please see the file LICENSE-GPL for details.
+ * GNU Lesser General Public License, as published by the Free Software
+ * Foundation; either version 2.1 of the License, or (at your option) any
+ * later version. Please see the file LICENSE-LGPL for details.
  *
  * Web Page: http://brltty.com/
  *
@@ -25,7 +25,7 @@ extern "C" {
 
 typedef enum {
   MSG_SILENT  = 0X1, /* don't speak the message */
-  MSG_WAITKEY = 0X2, /* wait for a key press before scrolling or dismissing the message */
+  MSG_LOG     = 0X2, /* add the message to the log's message stack */
   MSG_NODELAY = 0X4, /* don't wait */
   MSG_SYNC    = 0X8  /* run synchronously */
 } MessageOptions;
